import { ChatInputCommandInteraction, SlashCommandBuilder } from "discord.js";
import { IsNull } from "typeorm";
import { Badword, database } from "../data";
import { getGuildSetting, isPremiumActive } from "../tools/data";
import getDefaultEmbed from "../tools/defaultEmbeds";
import pack from "../../package.json";
import { Color, Emoji } from "../tools/design";

const builder = new SlashCommandBuilder();
builder.setName("info");
builder.setDescription("Shows information about this bot and the server settings");
builder.setDMPermission(false);

async function execute(interaction: ChatInputCommandInteraction): Promise<void> {
    if (!interaction.inGuild()) throw new Error("Command was executed outside guild context");

    const settings = await getGuildSetting(interaction.guildId);
    const isPremium = isPremiumActive(settings.isPremiumUntil);
    const globalBlockedWordsCount = await database.getRepository(Badword).count({
        where: {
            guildID: IsNull()
        }
    });
    const localBlockedWordsCount = await database.getRepository(Badword).count({
        where: {
            guildID: interaction.guildId
        }
    });

    const embed = getDefaultEmbed();
    embed.setTitle(`${Emoji.SECURITY_CHALLENGE} Channel filter V${pack.version} by AstroGD®`);
    embed.setDescription(`Codename eu.astrogd.white-leopard`);
    embed.setColor(isPremium ? Color.PREMIUM_ORANGE : Color.INFORMING_BLUE);
    embed.addFields({
        name: "What does this bot do?",
        value: "This bot checks for blocked words contained in channel names and reverts the changes if found."
    },{
        name: "Author",
        value: `This bot was created by AstroGD#0001 ${Emoji.ASTROGD} mainly for the official r/Overwatch2 Subreddit Discord server`
    },{
        name: "Server status",
        value: `${isPremium ? Emoji.PREMIUM : Emoji.SWITCH_OFF} Premium features are ${isPremium ? "enabled" : "disabled"} on this server`,
        inline: true
    },{
        name: "Global word count",
        value: globalBlockedWordsCount.toString(),
        inline: true
    },{
        name: "Local word count",
        value: localBlockedWordsCount.toString(),
        inline: true
    },{
        name: `${Emoji.WAVING} Have a question or want to say hello?`,
        value: "Join the support Discord server at https://go.astrogd.eu/discord"
    });

    interaction.reply({
        embeds: [embed],
        ephemeral: true
    }).catch();
}

export {
    builder,
    execute
}