import path from "path";
import { DataSource } from "typeorm";
import { config } from "dotenv";
import { Badword, GuildSetting } from "./model";

config();

const host = process.env["DB_HOST"];
const username = process.env["DB_USERNAME"];
const password = process.env["DB_PASSWORD"];
const database = process.env["DB_DATABASE"];

if (!host) throw new ReferenceError("Environment variable DB_HOST is missing");
if (!username) throw new ReferenceError("Environment variable DB_USERNAME is missing");
if (!password) throw new ReferenceError("Environment variable DB_PASSWORD is missing");
if (!database) throw new ReferenceError("Environment variable DB_DATABASE is missing");

const dataSource = new DataSource({
    type: "postgres",
    host: host,
    port: 5432,
    username: username,
    password: password,
    database: database,
    migrationsRun: true,
    migrations: [ path.join(__dirname, "/migrations/*") ],
    entities: [Badword,GuildSetting],
    migrationsTransactionMode: "each"
});

dataSource.initialize();

export default dataSource;